==> inqman_1.0.0.0.tar.gz: inqman/application/inqman/controllers/ErrorController.php <==
<?php
/*
 * This file is part of INQMAN
 *
 * Copyright(c) 2008 BULLHEAD,INC. ALL RIGHTS RESERVED.
 *
 * http://www.bullhead.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;
 * either version 3 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * ErrorController - The default error controller class
 * 
 * @author
 * @version 
 */
require_once 'Zend/Controller/Action.php';

class Inqman_ErrorController extends AbstractController
{
    public function preDispatch()
    {
        parent::preDispatch();
        /**認証チェック無し**/
    }
    
    protected function _setupDatabase()
    {
        /**データベース接続無し**/
    }

    /**
     * This action handles  
     *    - Application errors
     *    - Errors in the controller chain arising from missing 
     *      controller classes and/or action methods
     */
    public function errorAction()
    {
        $this->_setupPageTitle('application_error', 'error');
        
        $errors = $this->_getParam('error_handler');
        
        switch ($errors->type) {
            case Zend_Controller_Plugin_ErrorHandler::EXCEPTION_NO_CONTROLLER:
            case Zend_Controller_Plugin_ErrorHandler::EXCEPTION_NO_ACTION:
                // 404 error -- controller or action not found                
                $this->getResponse()->setRawHeader('HTTP/1.1 404 Not Found');
                $this->view->title = 'HTTP/1.1 404 Not Found';
                break;
            default:
                // application error; display error page, but don't change                
                // status code
                $this->view->title = $this->_translate->translate('error.title.application_error');
                break;
        }
        $this->_logger->err($errors->exception);
        
        $message = $errors->exception->getMessage();
        $this->view->message = $message;
    }
}

==> inqman_1.0.2.tar.gz: inqman/application/inqman/controllers/ErrorController.php <==
<?php
/*
 * This file is part of INQMAN
 *
 * Copyright(c) 2008 BULLHEAD,INC. ALL RIGHTS RESERVED.
 *
 * http://www.bullhead.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;
 * either version 3 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * ErrorController - The default error controller class
 * 
 * @author
 * @version 
 */
require_once 'Zend/Controller/Action.php';

class Inqman_ErrorController extends AbstractController
{
    public function preDispatch()
    {
        parent::preDispatch();
        /**認証チェック無し**/
    }
    
    protected function _setupDatabase()
    {
        /**データベース接続無し**/
    }

    /**
     * This action handles  
     *    - Application errors
     *    - Errors in the controller chain arising from missing 
     *      controller classes and/or action methods
     */
    public function errorAction()
    {
        $this->_setupPageTitle('application_error', 'error');
        
        $errors = $this->_getParam('error_handler');
        
        switch ($errors->type) {
            case Zend_Controller_Plugin_ErrorHandler::EXCEPTION_NO_CONTROLLER:
            case Zend_Controller_Plugin_ErrorHandler::EXCEPTION_NO_ACTION:
                // 404 error -- controller or action not found                
                $this->getResponse()->setRawHeader('HTTP/1.1 404 Not Found');
                $this->view->title = 'HTTP/1.1 404 Not Found';
                break;
            default:
                // application error; display error page, but don't change                
                // status code
                $this->view->title = $this->_translate->translate('error.title.application_error');
                break;
        }
        $this->_logger->err($errors->exception->getMessage());
        
        $message = $errors->exception->getMessage();
        $this->view->message = $message;
    }
}
